Class: Aws::WorkMailMessageFlow::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkMailMessageFlow::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workmailmessageflow/client.rb
Overview
An API client for WorkMailMessageFlow. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::WorkMailMessageFlow::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#get_raw_message_content(params = {}) ⇒ Types::GetRawMessageContentResponse
Retrieves the raw content of an in-transit email message, in MIME format.
-
#put_raw_message_content(params = {}) ⇒ Struct
Updates the raw content of an in-transit email message, in MIME format.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
588 589 590 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 588 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
591 592 593 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 591 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 561 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkMailMessageFlow') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workmailmessageflow' context[:gem_version] = '1.67.0' Seahorse::Client::Request.new(handlers, context) end |
#get_raw_message_content(params = {}) ⇒ Types::GetRawMessageContentResponse
Retrieves the raw content of an in-transit email message, in MIME format.
501 502 503 504 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 501 def (params = {}, = {}, &block) req = build_request(:get_raw_message_content, params) req.send_request(, &block) end |
#put_raw_message_content(params = {}) ⇒ Struct
Updates the raw content of an in-transit email message, in MIME format.
This example describes how to update in-transit email message. For more information and examples for using this API, see [ Updating message content with AWS Lambda].
<note markdown=“1”> Updates to an in-transit message only appear when you call ‘PutRawMessageContent` from an AWS Lambda function configured with a synchronous [ Run Lambda] rule. If you call `PutRawMessageContent` on a delivered or sent message, the message remains unchanged, even though [GetRawMessageContent] returns an updated message.
</note>
[1]: docs.aws.amazon.com/workmail/latest/adminguide/update-with-lambda.html [2]: docs.aws.amazon.com/workmail/latest/adminguide/lambda.html#synchronous-rules [3]: docs.aws.amazon.com/workmail/latest/APIReference/API_messageflow_GetRawMessageContent.html
552 553 554 555 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 552 def (params = {}, = {}) req = build_request(:put_raw_message_content, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
581 582 583 |
# File 'lib/aws-sdk-workmailmessageflow/client.rb', line 581 def waiter_names [] end |