Class: Aws::WorkMailMessageFlow::Types::InvalidContentLocation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-workmailmessageflow/types.rb

Overview

WorkMail could not access the updated email content. Possible reasons:

  • You made the request in a region other than your S3 bucket region.

  • The S3 bucket owner is not the same as the calling AWS account.

  • You have an incomplete or missing S3 bucket policy. For more information about policies, see Updating message content with AWS Lambda in the WorkMail Administrator Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


57
58
59
60
61
# File 'lib/aws-sdk-workmailmessageflow/types.rb', line 57

class InvalidContentLocation < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end